import argparse
import sys

from gron import gron

parser = argparse.ArgumentParser()
parser.add_argument(
    'file',
    help='A JSON file, if not given gron reads from STDIN',
    nargs='?',
    type=argparse.FileType('r'),
    default=sys.stdin)


def main():
    args = parser.parse_args()
    data = args.file.read()
    print(gron(data))


if __name__ == '__main__':
    main()



import json


def walk(node, name):
    if node is None:
        return "{name} = {value};".format(name=name, value='null')
    elif isinstance(node, bool):
        return "{name} = {value};".format(name=name, value=str(node).lower())
    elif isinstance(node, (str, bytes)):
        return '{name} = "{value}";'.format(name=name, value=node)
    elif isinstance(node, dict):
        res = []
        res.append("{name} = {{}};".format(name=name))
        for k, v in sorted(node.items()):
            res.append(walk(v, name + convert('.' + k)))
        res = '\n'.join(sorted(res))
        return res
    elif isinstance(node, (list, tuple)):
        res = []
        res.append("{name} = [];".format(name=name))
        for i, e in enumerate(node):
            res.append(walk(e, name + convert(str([i]))))
        res = '\n'.join(res)
        return res

    else:
        return "{name} = {value!r};".format(name=name, value=node)


def convert(name):
    if ('-' in name or ' ' in name):
        return '["{}"]'.format(name[1:])
    return name


def gron(input_):
    python = json.loads(input_)
    output = walk(python, 'json')
    return output



#!/usr/bin/env python


from setuptools import setup

meta = {}
exec(open('./gron/version.py').read(), meta)
meta['long_description'] = open('./README.md').read()

setup(name='gron',
      version=meta['__VERSION__'],
      description='Python library to grep JSON.',
      long_description=meta['long_description'],
      long_description_content_type='text/markdown',
      keywords='gron json cli',
      author='Bastian Venthur',
      author_email='mail@venthur.de',
      url='https://github.com/venthur/python-gron',
      python_requires='>=3',
      extras_require={
        'dev': [
            'pytest',
            'pytest-cov',
        ]
      },
      packages=['gron'],
      entry_points={
          'console_scripts': [
              'gron = gron.__main__:main'
          ]
      },
      license='MIT',
)
